@@ -13,8 +13,7 @@
 # limitations under the License.
 
 from .auto_client import AutoLLMClient
-from .tracer import Tracer
-from .types import ThinkingLevel
+from .types import PromptCaching, ThinkingLevel
 
 
-__all__ = ["AutoLLMClient", "ThinkingLevel", "Tracer"]
+__all__ = ["AutoLLMClient", "PromptCaching", "ThinkingLevel"]
